@@ -17,6 +17,18 @@ ERROR_RESPONSE_PREFIX = "Error response: "
 logger = logging.getLogger(__name__)
 
 
+def _err_msg_from_err_response(r: requests.Response) -> str:
+    # Typically I'm against exceptions for control flow, but meh it's readable
+    # in this case
+    try:
+        error_dict = json.loads(r.text)["error"]
+        err_msg = f"{error_dict['error_type']}: {error_dict['message']}"
+    except:  # noqa: E722
+        err_msg = r.text
+
+    return err_msg
+
+
 def read_config_files(config_dir: str) -> Dict:
     """Read yaml files from config_dir. Returns (file name, file contents) per file in dir"""
     assert os.path.exists(config_dir), f"User-specified config dir ({config_dir}) does not exist"
@@ -45,11 +57,9 @@ def read_config_files(config_dir: str) -> Dict:
                 try:
                     yaml.safe_load_all(results[filepath])
                 except yaml.parser.ParserError as e:
-                    raise yaml.parser.ParserError(
-                        f"Invalid yaml in config file at path: {filepath}. {ERROR_RESPONSE_PREFIX}'{e}'"
-                    )
+                    raise yaml.parser.ParserError(f"Invalid yaml in config file at path: {filepath}. {e}")
                 except Exception as e:
-                    raise Exception(f"Failed loading yaml config file. {ERROR_RESPONSE_PREFIX}{e}")
+                    raise Exception(f"Failed loading yaml config file. {e}")
 
                 results[fname] = f.read()
 
@@ -96,7 +106,7 @@ def commit_configs(
     logger.info("Uploading config files")
     r = requests.post(add_files_url, data=json.dumps(results).encode("utf-8"), headers=headers, verify=verify)
     if r.status_code != 200:
-        raise Exception(f"Failed uploading config yaml files. {ERROR_RESPONSE_PREFIX}{r.text}")
+        raise Exception(f"Failed uploading config yaml files. {r.text}")
 
     # This route validates the configs for files we just pushed and, if there are no
     # errors it then creates a semantic model from those configs in the backend database
@@ -110,7 +120,8 @@ def commit_configs(
         json=json.dumps({"is_current": False, "is_validation": is_validation}),
     )
     if r.status_code != 200:
-        raise Exception(f"{ERROR_RESPONSE_PREFIX}{r.text}")
+        err_msg = _err_msg_from_err_response(r)
+        raise Exception(err_msg)
     logger.info("Successfully committed configs")
 
     return r
@@ -185,9 +196,10 @@ def promote_model(
     logger.info("Promoting model")
     r = requests.post(promote_url, headers=auth_header, verify=verify)
     if r.status_code != 200:
-        raise Exception(f"{ERROR_RESPONSE_PREFIX}{r.text}")
-    logger.info("Successfully promoted model")
+        err_msg = _err_msg_from_err_response(r)
+        raise Exception(err_msg)
 
+    logger.info("Successfully promoted model")
     return r
 
 
@@ -227,23 +239,27 @@ if __name__ == "__main__":
     BRANCH = f"{BRANCH}"
     COMMIT = f"{COMMIT}"
 
-    if mode == UPLOAD_MODE_VALIDATE:
-        validate_configs(
-            auth_header=auth_header,
-            repo=REPO,
-            branch=BRANCH,
-            commit=COMMIT,
-            config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
-            api_url=API_URL,
-        )
-    else:  # mode == UPLOAD_MODE_COMMIT
-        commit_configs_as_primary(
-            auth_header=auth_header,
-            repo=REPO,
-            branch=BRANCH,
-            commit=COMMIT,
-            config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
-            api_url=API_URL,
-        )
+    try:
+        if mode == UPLOAD_MODE_VALIDATE:
+            validate_configs(
+                auth_header=auth_header,
+                repo=REPO,
+                branch=BRANCH,
+                commit=COMMIT,
+                config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
+                api_url=API_URL,
+            )
+        else:  # mode == UPLOAD_MODE_COMMIT
+            commit_configs_as_primary(
+                auth_header=auth_header,
+                repo=REPO,
+                branch=BRANCH,
+                commit=COMMIT,
+                config_dir=TRANSFORM_CONFIG_DIR or LOCAL_DIR_DEFAULT,
+                api_url=API_URL,
+            )
+    except Exception as e:
+        print(e)
+        sys.exit(1)
 
     print("success")
